#
# spec file for package mingw64-cross-binutils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mingw64-cross-binutils
Version:        2.42
Release:        1.5
Summary:        GNU Binutils
License:        GPL-2.0-or-later AND LGPL-2.1-or-later AND GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          Development/Libraries
URL:            http://www.gnu.org/software/binutils/
Source:         http://ftp.gnu.org/gnu/binutils/binutils-%{version}.tar.xz
Source1:        http://ftp.gnu.org/gnu/binutils/binutils-%{version}.tar.xz.sig
Patch0:         binutils-2.42-option-high-entry-va.patch
#!BuildIgnore:  post-build-checks
#!BuildIgnore:  mingw64-cross-binutils-utils
#!BuildIgnore:  mingw64-cross-pkgconf-utils
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  mingw64-filesystem
BuildRequires:  texinfo
Requires:       mingw64-cross-binutils-utils
# NB: This must be left in.
Requires:       mingw64-filesystem

%description
The GNU Binutils are a collection of binary tools.
These utilities (like 'as', 'ld', 'strip') understand Windows executables and DLLs.

%package -n mingw64-cross-binutils-utils
Summary:        Utilities for packaging support

%description -n mingw64-cross-binutils-utils
Utilities (like strip and objdump) which are needed for generating package

%prep
%autosetup -p1 -n binutils-%{version}

%build
mkdir -p build
cd build
CFLAGS="%{optflags}" \
../configure \
  --build=%{_build} --host=%{_host} \
  --target=%{_mingw64_target} \
  --verbose --disable-nls \
  --without-included-gettext \
  --disable-win32-registry \
  --disable-werror \
  --with-sysroot=%{_mingw64_sysroot} \
  --prefix=%{_prefix} --bindir=%{_bindir} \
  --includedir=%{_includedir} --libdir=/usr/%{_mingw64_target}/lib \
  --mandir=%{_mandir} --infodir=%{_infodir}

%make_build || make

%install
cd build
%make_install

# These files conflict with ordinary binutils.
rm -rf %{buildroot}%{_infodir}

for i in ar as dlltool ld ld.bfd nm objcopy objdump ranlib readelf strip; do
  rm -f %{buildroot}%{_bindir}/%{_mingw64_target}-$i;
  ln -s %{_prefix}/%{_mingw64_target}/bin/$i %{buildroot}%{_bindir}/%{_mingw64_target}-$i;
done

# mingw64-cross-binutils.x86_64: E: zero-length .../lib/ldscripts/stamp
for i in %{buildroot}%{_prefix}/%{_mingw64_target}/lib/ldscripts/stamp; do
  if test -f $i; then
    rm $i
  fi
done

%files
%{_mandir}/man1/*
%exclude %{_mandir}/man1/%{_mingw64_target}-nm.1.gz
%exclude %{_mandir}/man1/%{_mingw64_target}-objcopy.1.gz
%exclude %{_mandir}/man1/%{_mingw64_target}-objdump.1.gz
%exclude %{_mandir}/man1/%{_mingw64_target}-strip.1.gz
%{_bindir}/%{_mingw64_target}-*
%exclude %{_bindir}/%{_mingw64_target}-nm
%exclude %{_bindir}/%{_mingw64_target}-objcopy
%exclude %{_bindir}/%{_mingw64_target}-objdump
%exclude %{_bindir}/%{_mingw64_target}-strip
%{_prefix}/%{_mingw64_target}/bin
%exclude %{_prefix}/%{_mingw64_target}/bin/nm
%exclude %{_prefix}/%{_mingw64_target}/bin/objcopy
%exclude %{_prefix}/%{_mingw64_target}/bin/objdump
%exclude %{_prefix}/%{_mingw64_target}/bin/strip
%{_prefix}/%{_mingw64_target}/lib

%files utils
%{_mandir}/man1/%{_mingw64_target}-nm.1.gz
%{_mandir}/man1/%{_mingw64_target}-objcopy.1.gz
%{_mandir}/man1/%{_mingw64_target}-objdump.1.gz
%{_mandir}/man1/%{_mingw64_target}-strip.1.gz
%{_bindir}/%{_mingw64_target}-nm
%{_bindir}/%{_mingw64_target}-objcopy
%{_bindir}/%{_mingw64_target}-objdump
%{_bindir}/%{_mingw64_target}-strip
%{_prefix}/%{_mingw64_target}/bin/nm
%{_prefix}/%{_mingw64_target}/bin/objcopy
%{_prefix}/%{_mingw64_target}/bin/objdump
%{_prefix}/%{_mingw64_target}/bin/strip

%changelog
* Thu Jun 20 2024 Ralf Habacker <ralf.habacker@freenet.de>
- Fixes:
  * mingw64-binutils.spec: W: patch-fuzz-is-changed
  * "mingw64-binutils.keyring" is not mentioned in spec files as
    source or patch
  * mingw64-binutils.noarch: E: zero-length
    /usr/x86_64-w64-mingw32/lib/ldscripts/stamp
  * mingw64-binutils.src: E: unused-rpmlintrc-filter
    "arch-independent-package-contains-binary-or-object"
* Sat Jun 15 2024 Ralf Habacker <ralf.habacker@freenet.de>
- Fix "binutils-2.42.tar.xz.sig" is not mentioned in spec files as
  source or patch.
* Mon Jun  3 2024 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 2.42
- Removed patches that were included in the official version
  * 0001-dllwrap-windres-and-dlltools-use-mktemp-which-should.patch
  * 0001-Fix-bug-not-showing-correct-path-with-objdump-WL-wit.patch
  * 0001-PR29362-some-binutils-memory-leaks.patch
  * reproducible.patch
- Add patch
  * binutils-2.42-option-high-entry-va.patch
- Removed patch
  * binutils-2.39-option-high-entry-va.patch
* Fri May 31 2024 Ralf Habacker <ralf.habacker@freenet.de>
- Add patch to enable HEASLR with PE builds which is a leftover from
    https://sourceware.org/bugzilla/show_bug.cgi?id=19011 (boo#948280)
  * binutils-2.39-option-high-entry-va.patch
* Fri Oct  6 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to override build date (boo#1047218)
* Thu Nov 10 2022 Ralf Habacker <ralf.habacker@freenet.de>
- Move utilities needed for packaging into a separate utils package
  to fix (boo#1204985)
- Add #!BuildIgnore: mingw64-cross-binutils|pkgconf-utils to prevent
  unresolved build dependency
- Removed trailing spaces in this file
* Thu Nov  3 2022 Ralf Habacker <ralf.habacker@freenet.de>
- Fix cyclic dependency (boo#1204985)
* Mon Aug 22 2022 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 2.39
- Add patch to fix memory leak in objdump bug, see
  https://sourceware.org/bugzilla/show_bug.cgi?id=29505 for details
  * 0001-PR29362-some-binutils-memory-leaks.patch
- Add patch to fix issue with objdump -WL, see
  https://sourceware.org/bugzilla/show_bug.cgi?id=29523
  * 0001-Fix-bug-not-showing-correct-path-with-objdump-WL-wit.patch
- Add patch to fix warning: 'call-to-mktemp ...'
  https://sourceware.org/bugzilla/show_bug.cgi?id=29534
  * 0001-dllwrap-windres-and-dlltools-use-mktemp-which-should.patch
- Sync with mingw32 variant
* Wed Jun 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to version 2.38
- Drop 0001-Fix-a-potential-infinite-loop-in-the-Windows-resourc.patch,
  0001-Fix-the-windmc-program-to-conform-to-the-behaviour-o.patch
* Tue Jun  9 2020 Ralf Habacker <ralf.habacker@freenet.de>
- Add patches to fix (boo#920134)
  * 0001-Fix-a-potential-infinite-loop-in-the-Windows-resourc.patch
  * 0001-Fix-the-windmc-program-to-conform-to-the-behaviour-o.patch
  (removed conflicting changelog entry)
* Fri Feb  7 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Build only on x86* archs
* Sun Nov 24 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 2.33.1
- Drop 0001-COFF-Check-for-symbols-defined-in-discarded-section.patch
  Fixed upstream.
* Wed Nov 20 2019 Ludwig Nussel <lnussel@suse.de>
- inital package for Factory submission
